@@ -20,6 +20,7 @@ from __future__ import annotations
 
 import dataclasses
 import logging
+import random
 from datetime import date, datetime
 from typing import Mapping, Optional, Sequence
 
@@ -111,7 +112,7 @@ Key for the validation context to indicate that the input data is trusted.
 
 
 def is_input_trusted_according_to_validation_context(
-    validation_context: Optional[Mapping[str, object]]
+    validation_context: Optional[Mapping[str, object]],
 ) -> bool:
     """
     Return whether the input data is trusted according to the validation context.
@@ -206,6 +207,36 @@ class DteNaturalKey:
             validate_dte_folio(v)
         return v
 
+    ############################################################################
+    # class methods
+    ############################################################################
+
+    @classmethod
+    def random(
+        cls,
+        emisor_rut: Optional[Rut] = None,
+        tipo_dte: TipoDte | Sequence[TipoDte] = tuple(TipoDte),
+        folio: int | tuple[int, int] = (
+            constants.DTE_FOLIO_FIELD_MIN_VALUE,
+            constants.DTE_FOLIO_FIELD_MAX_VALUE,
+        ),
+    ) -> Self:
+        """
+        Generate random DTE natural key within valid ranges.
+
+        :param emisor_rut: RUT of the "emisor" of the DTE. If `None`, a random RUT is generated.
+        :param tipo_dte: The kind of DTE. If a sequence is provided, a random one is chosen.
+        :param folio: The sequential number of the DTE. If a 2-tuple of integers is provided,
+            a random one is chosen within the range defined by the tuple.
+        """
+        if emisor_rut is None:
+            emisor_rut = Rut.random()
+        if isinstance(tipo_dte, Sequence):
+            tipo_dte = random.choice(tipo_dte)
+        if isinstance(folio, tuple):
+            folio = random.randint(*folio)
+        return cls(emisor_rut, tipo_dte, folio)
+
 
 @pydantic.dataclasses.dataclass(
     frozen=True,
